pub type RustPluginFn = fn(&mut Host<'_>, &[GenericValue]) -> Result<GenericValue, PluginError>;Expand description
Signature of a Rust plugin function used with export_module!.
pub type RustPluginFn = fn(&mut Host<'_>, &[GenericValue]) -> Result<GenericValue, PluginError>;Signature of a Rust plugin function used with export_module!.