pub type RustPluginValueFn = fn(&mut Host<'_>) -> Result<GenericValue, PluginError>;Expand description
Signature of a Rust plugin value creator used with export_module!:
builds one module constant at import time.
pub type RustPluginValueFn = fn(&mut Host<'_>) -> Result<GenericValue, PluginError>;Signature of a Rust plugin value creator used with export_module!:
builds one module constant at import time.